==> haskell-rank2classes-1.5.4-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-4HjerxTypD7JpagILCPDcj
key:                  rank2classes-1.5.4-4HjerxTypD7JpagILCPDcj
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  9c7159af321bf0d0d5e9c6f6ea843d42
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-4HjerxTypD7JpagILCPDcj
depends:
    base-4.17.2.1 data-functor-logistic-0.0-2B6t99xvfbK3XWgdkwyMyw
    distributive-0.6.2.1-CYwgdClE26GLAL3gsDf3Vu
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rank2classes-1.5.4-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rank2classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rank2classes
version:              1.5.4
visibility:           public
id:                   rank2classes-1.5.4-2NKRSHIxjRqLi2lzxldtBg
key:                  rank2classes-1.5.4-2NKRSHIxjRqLi2lzxldtBg
license:              BSD-3-Clause
copyright:            (c) 2017 Mario Blažević
maintainer:           Mario Blažević <blamario@protonmail.com>
author:               Mario Blažević
homepage:             https://github.com/blamario/grampa/tree/master/rank2classes
synopsis:
    standard type constructor class hierarchy, only with methods of rank 2 types

description:
    A mirror image of the standard type constructor class hierarchy rooted in '\''Functor'\'', except with methods of rank 2
    types and class instances of kind @(k->*)->*@. The classes enable generic handling of heterogenously typed data
    structures and other neat tricks.

category:             Control, Data, Generics
abi:                  ea33b7a8a15888480c7c64c30184a2bb
exposed:              True
exposed-modules:      Rank2 Rank2.TH
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rank2classes-1.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rank2classes
hs-libraries:         HSrank2classes-1.5.4-2NKRSHIxjRqLi2lzxldtBg
depends:
    base-4.17.2.1 data-functor-logistic-0.0-889o70VVTEBngB0mGdW6y
    distributive-0.6.2.1-IRNu7pDowxUB62etqvswDi
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-rank2classes/html/rank2classes.haddock

haddock-html:         /usr/share/doc/haskell-rank2classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
